/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#pragma once

namespace U2 {

#define ADV_MENU_ANALYSE "ADV_MENU_ANALYSE"
#define ADV_MENU_COPY "ADV_MENU_COPY"
#define ADV_COPY_TRANSLATION_ACTION "ADV_COPY_TRANSLATION_ACTION"
#define ADV_MENU_SELECT "ADV_MENU_SELECT"
#define ADV_MENU_ADD "ADV_MENU_ADD"
#define ADV_MENU_REMOVE "ADV_MENU_REMOVE"
#define ADV_MENU_ZOOM "ADV_MENU_ZOOM"
#define ADV_MENU_ALIGN "ADV_MENU_ALIGN"
#define ADV_MENU_EXPORT "ADV_MENU_EXPORT"
#define ADV_GOTO_ACTION "ADV_GOTO_ACTION"
#define ADV_MENU_SECTION1_SEP "ADV_MENU_SEC1_SEP"
#define ADV_MENU_SECTION2_SEP "ADV_MENU_SEC2_SEP"
#define ADV_MENU_EDIT "ADV_MENU_EDIT"
#define ADV_MENU_REPLACE_WHOLE_SEQUENCE "ADV_MENU_REPLACE_WHOLE_SEQUENCE"

#define SEQ_EDIT_SETTINGS_ROOT "sequence_edit_settings/"
#define SEQ_EDIT_SETTINGS_ANNOTATION_STRATEGY "annotation_strategy"
#define SEQ_EDIT_SETTINGS_RECALC_QUALIFIERS "recalculate_qualifiers"

#define ANNOTATED_DNA_VIEW_FACTORY_ID "AnnotatedDNAView"

}  // namespace U2
